package com.wzy.auth.service.impl;

import com.alibaba.fastjson.JSONObject;
import com.wzy.auth.feign.UserFeignService;
import com.wzy.auth.service.AuthService;
import com.wzy.common.constants.JwtConstants;
import com.wzy.common.constants.TokenConstants;
import com.wzy.common.domain.User;
import com.wzy.common.domain.request.LoginRequest;
import com.wzy.common.domain.response.JwtResponse;
import com.wzy.common.result.Result;
import com.wzy.common.utils.JwtUtils;
import com.wzy.common.utils.StringUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.data.redis.core.RedisTemplate;
import org.springframework.stereotype.Service;

import javax.servlet.http.HttpServletRequest;
import java.util.HashMap;
import java.util.UUID;
import java.util.concurrent.TimeUnit;

@Service
public class AuthServiceImpl implements AuthService {

    @Autowired
    private UserFeignService userFeignService;

    @Autowired
    private RedisTemplate<String,String> redisTemplate;

    @Autowired
    private HttpServletRequest request;
    @Override
    public Result<JwtResponse> login(LoginRequest loginRequest) {
        Result<User> byUserName = userFeignService.login(loginRequest.getUserName());
        User data = byUserName.getData();

        if (null == data){
            return Result.error("用户不存在");
        }

        if (StringUtils.isAllEmpty(loginRequest.getUserName(),loginRequest.getUserPwd())){
            return Result.error("用户或密码不能为空");
        }

        if (!loginRequest.getUserPwd().equals(data.getUserPwd())){
            return Result.error("密码错误");
        }

        String userKey = UUID.randomUUID().toString().replaceAll("-", "");
        HashMap<String, Object> map = new HashMap<>();
        map.put(JwtConstants.USER_KEY,userKey);
        String token = JwtUtils.createToken(map);
        redisTemplate.opsForValue().set(TokenConstants.LOGIN_TOKEN_KEY+userKey, JSONObject.toJSONString(data),50, TimeUnit.MINUTES);

        JwtResponse jwtResponse = new JwtResponse();
        jwtResponse.setExpireTime("50MIN");
        jwtResponse.setToken(token);
        return Result.success(jwtResponse);
    }

    @Override
    public User userInfo() {
        String token = request.getHeader(TokenConstants.TOKEN);
        String userKey = JwtUtils.getUserKey(token);
        String s = redisTemplate.opsForValue().get(TokenConstants.LOGIN_TOKEN_KEY + userKey);
        return JSONObject.parseObject(s,User.class);
    }

    @Override
    public void logout() {
        String token = request.getHeader(TokenConstants.TOKEN);
        String userKey = JwtUtils.getUserKey(token);
        redisTemplate.delete(TokenConstants.LOGIN_TOKEN_KEY + userKey);
    }
}
