package com.wzy.servers.controller;

import com.alibaba.fastjson.JSONObject;
import com.wzy.common.domain.Mine;
import com.wzy.common.domain.Rebate;
import com.wzy.common.domain.Servers;
import com.wzy.common.domain.User;
import com.wzy.common.domain.request.Req;
import com.wzy.common.result.Result;
import com.wzy.servers.service.ServersService;
import lombok.extern.log4j.Log4j2;
import org.springframework.web.bind.annotation.*;
import org.springframework.web.multipart.MultipartFile;

import javax.servlet.http.HttpServletRequest;
import java.util.List;

@RestController
@Log4j2
public class ServersController {

    private final ServersService serversService;

    private final HttpServletRequest request;

    public ServersController(ServersService serversService, HttpServletRequest request) {
        this.serversService = serversService;
        this.request = request;
    }

    @PostMapping("/list")
    public Result<List<Servers>> list(@RequestBody Servers servers){
        return serversService.list(servers);
    }

    @PostMapping("/shopServers")
    public Result shopServers(@RequestBody Mine mine){
        log.info("功能:购买服务器,请求URI:{},请求方式:{},请求参数:{}",request.getRequestURI(),
                request.getMethod(),mine);
        Result result = serversService.shopServers(mine);
        log.info("功能:购买服务器,请求URI:{},请求方式:{},响应结果:{}",request.getRequestURI(),
                request.getMethod(), JSONObject.toJSONString(result));
        return result;
    }

    @PostMapping("/updateUser")
    public Result updateUser(@RequestBody User user){
        log.info("功能:更新用户信息,请求URI:{},请求方式:{},请求参数:{}",request.getRequestURI(),
                request.getMethod(),user);
        Result result = serversService.updateUser(user);
        log.info("功能:更新用户信息,请求URI:{},请求方式:{},响应结果:{}",request.getRequestURI(),
                request.getMethod(),JSONObject.toJSONString(result));
        return result;
    }

    @PostMapping("/rebateAdd")
    public Result rebateAdd(@RequestBody Rebate rebate){
        log.info("功能:返利记录,请求URI:{},请求方式:{},请求参数:{}",request.getRequestURI(),
                request.getMethod(),rebate);
        Result result = serversService.rebateAdd(rebate);
        log.info("功能:返利记录,请求URI:{},请求方式:{},响应结果:{}",request.getRequestURI(),
                request.getMethod(),JSONObject.toJSONString(result));
        return result;
    }

    @PostMapping("/mineList")
    public Result mineList(@RequestBody Req req){
        return serversService.mineList(req);
    }

    @PostMapping("/updateStart")
    public Result updateStart(@RequestBody Mine mine){
        return serversService.updateStart(mine);
    }

    @PostMapping("/del/{mineId}")
    public Result del(@PathVariable String mineId){
        return serversService.del(mineId);
    }

    @PostMapping("/rebateAdd1")
    public Result rebateAdd1(@RequestBody Rebate rebate){
        log.info("功能:返利记录,请求URI:{},请求方式:{},请求参数:{}",request.getRequestURI(),
                request.getMethod(),rebate);
        Result result = serversService.rebateAdd1(rebate);
        log.info("功能:返利记录,请求URI:{},请求方式:{},响应结果:{}",request.getRequestURI(),
                request.getMethod(),JSONObject.toJSONString(result));
        return result;
    }

    @PostMapping("/updateUser1")
    public Result updateUser1(@RequestBody User user){
        log.info("功能:更新用户信息,请求URI:{},请求方式:{},请求参数:{}",request.getRequestURI(),
                request.getMethod(),user);
        Result result = serversService.updateUser1(user);
        log.info("功能:更新用户信息,请求URI:{},请求方式:{},响应结果:{}",request.getRequestURI(),
                request.getMethod(),JSONObject.toJSONString(result));
        return result;
    }

    @PostMapping("/upload")
    public Result upload(@RequestParam("file")MultipartFile multipartFile){
        Result result = serversService.upload(multipartFile);
        return result;
    }
}
