package com.wzy.servers.service.impl;

import com.alibaba.fastjson.JSONObject;
import com.wzy.common.constants.TokenConstants;
import com.wzy.common.domain.Mine;
import com.wzy.common.domain.Rebate;
import com.wzy.common.domain.Servers;
import com.wzy.common.domain.User;
import com.wzy.common.domain.request.Req;
import com.wzy.common.result.Result;
import com.wzy.common.utils.FastUtil;
import com.wzy.common.utils.JwtUtils;
import com.wzy.servers.mapper.ServersMapper;
import com.wzy.servers.service.ServersService;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.data.redis.core.RedisTemplate;
import org.springframework.stereotype.Service;
import org.springframework.web.multipart.MultipartFile;

import javax.servlet.http.HttpServletRequest;
import java.util.ArrayList;
import java.util.List;
import java.util.Set;

@Service
public class ServersServiceImpl implements ServersService {

    @Autowired
    private ServersMapper serversMapper;

    @Autowired
    private RedisTemplate<String,String> redisTemplate;

    @Autowired
    private HttpServletRequest request;

    @Autowired
    private FastUtil fastUtil;

    @Override
    public Result list(Servers servers) {
        List<Servers> list = serversMapper.list(servers);
        return Result.success(list);
    }

    @Override
    public Result shopServers(Mine mine) {
        User user = userInfo();
        if (!user.getUserName().equals(mine.getMineName())) {
            if (user.getUserPrice()-mine.getServerPrice() >= 0) {
                int i = serversMapper.shopServers(mine);
                if (i > 0) {
                    return Result.success(i,"购买成功");
                } else {
                    return Result.error("请求失败");
                }
            } else {
                return Result.error("余额不足");
            }
        } else {
            return Result.error("自己不能推荐自己");
        }
    }

    @Override
    public Result updateUser(User user) {
        int i = serversMapper.updateUser(user);
        if (i > 0) {
            return Result.success(i,"用户信息更新成功");
        } else {
            return Result.error("请求失败");
        }
    }

    @Override
    public Result rebateAdd(Rebate rebate) {
        int i = serversMapper.rebateAdd(rebate);
        if (i > 0) {
            return Result.success(i,"返利记录更新成功");
        } else {
            return Result.error("请求失败");
        }
    }

    @Override
    public Result mineList(Req req) {
        Set<String> zset = redisTemplate.opsForZSet().reverseRange("hhh", 0, -1);
        List<Mine> list;
        if (null == zset || zset.isEmpty()) {
            list = serversMapper.queryList(req);
            for (Mine mine : list) {
                redisTemplate.opsForZSet().add("hhh",JSONObject.toJSONString(mine),mine.getServerPrice());
            }
            zset = redisTemplate.opsForZSet().reverseRange("hhh",0,-1);
        } else {
            list = new ArrayList<>();
            for (String s : zset) {
                list.add(JSONObject.parseObject(s,Mine.class));
            }
        }
        return Result.success(list);
    }

    @Override
    public Result updateStart(Mine mine) {
        int i = serversMapper.updateStart(mine);
        if (i > 0) {
            return Result.success(i,"申请退款");
        } else {
            return Result.error("请求失败");
        }
    }

    @Override
    public Result del(String mineId) {
        int i = serversMapper.del(mineId);
        if (i > 0) {
            return Result.success(i,"退货成功");
        } else {
            return Result.error("请求失败");
        }
    }

    @Override
    public Result rebateAdd1(Rebate rebate) {
        int i = serversMapper.rebateAdd1(rebate);
        if (i > 0) {
            return Result.success(i,"返利记录更新成功");
        } else {
            return Result.error("请求失败");
        }
    }

    @Override
    public Result updateUser1(User user) {
        int i = serversMapper.updateUser1(user);
        if (i > 0) {
            return Result.success(i,"用户信息更新成功");
        } else {
            return Result.error("请求失败");
        }
    }

    @Override
    public Result upload(MultipartFile multipartFile) {
        String upload = null;

        try {
            upload = fastUtil.upload(multipartFile);
            if (null == upload) {
                return Result.error("上传失败");
            }
        } catch (Exception e) {
            throw new RuntimeException(e);
        }
        return Result.success("http://165.154.161.166:8888/"+upload,"上传成功");
    }


    public User userInfo() {
        String token = request.getHeader(TokenConstants.TOKEN);
        String userKey = JwtUtils.getUserKey(token);
        String s = redisTemplate.opsForValue().get(TokenConstants.LOGIN_TOKEN_KEY + userKey);
        return JSONObject.parseObject(s,User.class);
    }
}
